@@ -27,6 +27,7 @@ local M = {}
 -- Re-export bundled modules
 M.List = require 'pandoc.List'
 M.mediabag = require 'pandoc.mediabag'
+M.system = require 'pandoc.system'
 M.utils = require 'pandoc.utils'
 M.text = require 'text'
 
@@ -845,7 +846,10 @@ local AttributeList = {
 
   __newindex = function (t, k, v)
     local cur, idx = List.find_if(t, assoc_key_equals(k))
-    if v == nil then
+    if v == nil and not cur then
+      -- deleted key does not exists in list
+      return
+    elseif v == nil then
       table.remove(t, idx)
     elseif cur then
       cur[2] = v
